==> vidjil-2014.02.tgz: vidjil-2014.02/algo/tests/testBugs.cpp <==
#include <core/fasta.h>
#include <core/kmerstore.h>
#include <core/kmeraffect.h>
#include <core/affectanalyser.h>
#include <core/segment.h>
#include <iostream>

using namespace std;

void testSegmentationBug1(int delta_min, int delta_max) {
  string buggy_sequences = "bugs/kmersegment.fa";
  int k = 14;
  bool rc = true;
  Fasta seqV("../../germline/TRGV.fa");
  Fasta seqJ("../../germline/TRGJ.fa");

  IKmerStore<KmerAffect>  *index = new ArrayKmerStore<KmerAffect>(k, rc);
  index->insert(seqV, "V");
  index->insert(seqJ, "J");

  OnlineFasta input(buggy_sequences);

  while (input.hasNext()) {
    input.next();
    KmerAffectAnalyser<KmerAffect> *kaa = new KmerAffectAnalyser<KmerAffect>(*index, input.getSequence().sequence);

    set<KmerAffect> distinct_a = kaa->getDistinctAffectations();
    int strand = 0;
    for (set<KmerAffect>::iterator it = distinct_a.begin(); 
         it != distinct_a.end() && strand != 2; it++) {
      if (! it->isAmbiguous() && ! it->isUnknown()) {
        if (strand == 0)
          strand = affect_strand(it->affect);
        else if ((strand == 1 && affect_strand(it->affect) == -1)
                 || (strand == -1 && affect_strand(it->affect) == 1))
          strand = 2;
      }
    }

    Segmenter *segment = new KmerSegmenter(input.getSequence(), index, 
                                           delta_min, delta_max);

    if (strand == 2 
        || (strand == 1
            && (kaa->last(AFFECT_V) == (int)string::npos
                || kaa->first(AFFECT_J) == (int) string::npos))
        || (strand == -1
            && (kaa->first(AFFECT_V) == (int)string::npos
                || kaa->last(AFFECT_J) == (int) string::npos)))
      TAP_TEST(! segment->isSegmented(), TEST_BUG_SEGMENTATION, "");
      
    delete segment;
    delete kaa;
  }
  delete index;
}

void testBugs() {
  testSegmentationBug1(-10, 15);
}

==> vidjil-2014.10.tgz: vidjil-2014.10/algo/tests/testBugs.cpp <==
#include <core/fasta.h>
#include <core/kmerstore.h>
#include <core/kmeraffect.h>
#include <core/affectanalyser.h>
#include <core/segment.h>
#include <iostream>

using namespace std;

void testSegmentationBug1(int delta_min, int delta_max) {
  string buggy_sequences = "bugs/kmersegment.fa";
  int k = 14;
  bool rc = true;
  Fasta seqV("../../germline/TRGV.fa");
  Fasta seqJ("../../germline/TRGJ.fa");

  Germline *germline ;
  germline = new Germline("custom", 'x', seqV, seqV, seqJ, delta_min, delta_max);
  germline->new_index("##############");

  MultiGermline *multi ;
  multi = new MultiGermline();
  multi->insert(germline);
  
  OnlineFasta input(buggy_sequences);

  while (input.hasNext()) {
    input.next();
    KmerAffectAnalyser<KmerAffect> *kaa = new KmerAffectAnalyser<KmerAffect>(*(germline->index), input.getSequence().sequence);

    set<KmerAffect> distinct_a = kaa->getDistinctAffectations();
    int strand = 0;
    for (set<KmerAffect>::iterator it = distinct_a.begin(); 
         it != distinct_a.end() && strand != 2; it++) {
      if (! it->isAmbiguous() && ! it->isUnknown()) {
        if (strand == 0)
          strand = affect_strand(it->affect);
        else if ((strand == 1 && affect_strand(it->affect) == -1)
                 || (strand == -1 && affect_strand(it->affect) == 1))
          strand = 2;
      }
    }

    Segmenter *segment = new KmerSegmenter(input.getSequence(), multi);


    if (strand == 2 
        || (strand == 1
            && (kaa->last(AFFECT_V) == (int)string::npos
                || kaa->first(AFFECT_J) == (int) string::npos))
        || (strand == -1
            && (kaa->first(AFFECT_V) == (int)string::npos
                || kaa->last(AFFECT_J) == (int) string::npos)))
      TAP_TEST(! segment->isSegmented(), TEST_BUG_SEGMENTATION, "");
      
    delete segment;
    delete kaa;
  }
  delete multi;
}

void testBugs() {
  testSegmentationBug1(-10, 15);
}
